@@ -1,12 +1,11 @@
 """Factor Investing Library"""
 
-__all__ = ['helpers', 'oanda', 'utils']
-__author__ = 'Paweł Kowalski'
+__all__ = ["helpers", "oanda", "utils"]
+__author__ = "Paweł Kowalski"
+
+from contextlib import suppress
 
 from pkg_resources import get_distribution, DistributionNotFound
 
-try:
+with suppress(DistributionNotFound):
     __version__ = get_distribution(__name__).version
-except DistributionNotFound:
-     # package is not installed
-    pass
